@@ -49,7 +49,6 @@
 
 package com.openexchange.mail.categories.json;
 
-import java.util.Collection;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicReference;
 import com.google.common.collect.ImmutableMap;
@@ -94,11 +93,6 @@ public class MailCategoriesActionFactory implements AJAXActionServiceFactory {
         this.actions = actions.build();
     }
 
-    @Override
-    public Collection<? extends AJAXActionService> getSupportedServices() {
-        return java.util.Collections.unmodifiableCollection(actions.values());
-    }
-
     @Override
     public AJAXActionService createActionService(final String action) throws OXException {
         return actions.get(action);
